@@ -158,16 +158,17 @@ func (a *HookAuth) SaveUser() (*users.User, error) {
 
 		// create user with the provided credentials
 		d := &users.User{
-			Username:     a.Cred.Username,
-			Password:     pass,
-			Scope:        a.Settings.Defaults.Scope,
-			Locale:       a.Settings.Defaults.Locale,
-			ViewMode:     a.Settings.Defaults.ViewMode,
-			SingleClick:  a.Settings.Defaults.SingleClick,
-			Sorting:      a.Settings.Defaults.Sorting,
-			Perm:         a.Settings.Defaults.Perm,
-			Commands:     a.Settings.Defaults.Commands,
-			HideDotfiles: a.Settings.Defaults.HideDotfiles,
+			Username:              a.Cred.Username,
+			Password:              pass,
+			Scope:                 a.Settings.Defaults.Scope,
+			Locale:                a.Settings.Defaults.Locale,
+			ViewMode:              a.Settings.Defaults.ViewMode,
+			SingleClick:           a.Settings.Defaults.SingleClick,
+			RedirectAfterCopyMove: a.Settings.Defaults.RedirectAfterCopyMove,
+			Sorting:               a.Settings.Defaults.Sorting,
+			Perm:                  a.Settings.Defaults.Perm,
+			Commands:              a.Settings.Defaults.Commands,
+			HideDotfiles:          a.Settings.Defaults.HideDotfiles,
 		}
 		u = a.GetUser(d)
 
@@ -219,13 +220,14 @@ func (a *HookAuth) GetUser(d *users.User) *users.User {
 		Download: isAdmin || a.Fields.GetBoolean("user.perm.download", d.Perm.Download),
 	}
 	user := users.User{
-		ID:          d.ID,
-		Username:    d.Username,
-		Password:    d.Password,
-		Scope:       a.Fields.GetString("user.scope", d.Scope),
-		Locale:      a.Fields.GetString("user.locale", d.Locale),
-		ViewMode:    users.ViewMode(a.Fields.GetString("user.viewMode", string(d.ViewMode))),
-		SingleClick: a.Fields.GetBoolean("user.singleClick", d.SingleClick),
+		ID:                    d.ID,
+		Username:              d.Username,
+		Password:              d.Password,
+		Scope:                 a.Fields.GetString("user.scope", d.Scope),
+		Locale:                a.Fields.GetString("user.locale", d.Locale),
+		ViewMode:              users.ViewMode(a.Fields.GetString("user.viewMode", string(d.ViewMode))),
+		SingleClick:           a.Fields.GetBoolean("user.singleClick", d.SingleClick),
+		RedirectAfterCopyMove: a.Fields.GetBoolean("user.redirectAfterCopyMove", d.RedirectAfterCopyMove),
 		Sorting: files.Sorting{
 			Asc: a.Fields.GetBoolean("user.sorting.asc", d.Sorting.Asc),
 			By:  a.Fields.GetString("user.sorting.by", d.Sorting.By),
@@ -251,6 +253,7 @@ var validHookFields = []string{
 	"user.locale",
 	"user.viewMode",
 	"user.singleClick",
+	"user.redirectAfterCopyMove",
 	"user.sorting.by",
 	"user.sorting.asc",
 	"user.commands",
